#!perl

BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}


use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::Perl::Critic::Subset 3.001.003

use Test::Perl::Critic (-profile => "") x!! -e "";

my $filenames = ['lib/Log/ger/Manual.pm','lib/Log/ger/Manual/FAQ.pod','lib/Log/ger/Manual/ForLog4perl.pod','lib/Log/ger/Manual/ForLogAny.pod','lib/Log/ger/Manual/ForLogContextual.pod','lib/Log/ger/Manual/ForLogDispatch.pod','lib/Log/ger/Manual/ForLogDispatchouli.pod','lib/Log/ger/Manual/Internals.pod','lib/Log/ger/Manual/Tips.pm','lib/Log/ger/Manual/Tutorial.pod','lib/Log/ger/Manual/Tutorial/100_WhatIsLogging.pod','lib/Log/ger/Manual/Tutorial/200_LoggingWithLogGer.pod','lib/Log/ger/Manual/Tutorial/300_Level.pod','lib/Log/ger/Manual/Tutorial/400_Output.pod','lib/Log/ger/Manual/Tutorial/41_Output_Screen.pod','lib/Log/ger/Manual/Tutorial/420_Output_File.pod','lib/Log/ger/Manual/Tutorial/421_Output_SimpleFile.pod','lib/Log/ger/Manual/Tutorial/422_Output_FileWriteRotate.pod','lib/Log/ger/Manual/Tutorial/43_Output_Syslog.pod','lib/Log/ger/Manual/Tutorial/47_Output_DirwriteRotate.pod','lib/Log/ger/Manual/Tutorial/481_Output_Composite.pod','lib/Log/ger/Manual/Tutorial/49_WritingAnOutputPlugin.pod','lib/Log/ger/Manual/Tutorial/500_Category.pod','lib/Log/ger/Manual/Tutorial/600_Format.pod','lib/Log/ger/Manual/Tutorial/61_Format_Block.pod','lib/Log/ger/Manual/Tutorial/69_WritingAFormatPlugin.pod','lib/Log/ger/Manual/Tutorial/700_Layout.pod','lib/Log/ger/Manual/Tutorial/79_WritingALayoutPlugin.pod','lib/Log/ger/Manual/Tutorial/800_Other_Plugin.pod','lib/Log/ger/Manual/Tutorial/81_Plugin_OptAway.pod','lib/Log/ger/Manual/Tutorial/89_WritingAPlugin.pod','lib/Log/ger/Manual/Tutorial/900_OtherTopics.pod','lib/Log/ger/Manual/Tutorial/91_Performance.pod','lib/Log/ger/Manual/Tutorial/92_Security.pod','lib/Log/ger/Manual/Tutorial/931_UsingInApplication.pod','lib/Log/ger/Manual/Tutorial/932_UsingWithLogGerApp.pod','lib/Log/ger/Manual/Tutorial/933_UsingWithPerinciCmdLine.pod','lib/Log/ger/Manual/Tutorial/934_UsingWithMooMoose.pod'];
unless ($filenames && @$filenames) {
    $filenames = -d "blib" ? ["blib"] : ["lib"];
}

all_critic_ok(@$filenames);
